@@ -14,6 +14,7 @@ mod genesis;
 pub mod melvm;
 mod stake;
 mod state;
+mod txbuilder;
 mod units;
 pub use state::melmint::*;
 pub use units::*;
@@ -28,7 +29,7 @@ pub use state::melswap::PoolState;
 pub use state::*;
 use std::ops::{Deref, DerefMut};
 pub use transaction::*;
-
+pub use txbuilder::*;
 pub mod melpow;
 
 #[cfg(test)]
